==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Nachrichtenzentrale</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Abpinnen</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Anpinnen</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Benachrichtigungs-Einstellungen</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Gerade eben</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>vor %1 Minuten</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>vor 1 Stunde</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>vor %1 Stunden</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Gestern</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Nachrichtenzentrale</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Abpinnen</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Anpinnen</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Benachrichtigungs-Einstellungen</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Gerade eben</translation>
    </message>
</context>
</TS>
